Module: Icons::Configuration::Feather
Instance Method Summary collapse
Instance Method Details
#config ⇒ Object
10 11 12 13 14 15 16 17 |
# File 'lib/icons/configuration/feather.rb', line 10 def config Options.new.tap do || .default_variant = nil .exclude_variants = [] .default = end end |
#initializer_config ⇒ Object
19 20 21 22 23 24 25 26 27 28 29 |
# File 'lib/icons/configuration/feather.rb', line 19 def initializer_config <<~RB.indent(2) # Override Feather defaults # config.libraries.feather.default_variant = "" # Feather has no variants, this is provided for backwards compatibility # config.libraries.feather.exclude_variants = [] # Feather has no variants, this is provided for backwards compatibility # config.libraries.feather.default.css = "size-6" # config.libraries.feather.default.stroke_width = "2" # config.libraries.feather.default.data = {} RB end |
#source ⇒ Object
31 32 33 34 35 36 37 38 |
# File 'lib/icons/configuration/feather.rb', line 31 def source { url: "https://github.com/feathericons/feather.git", variants: { ".": "icons" # Feather has no variants, store in the top directory } } end |